@@ -22,18 +22,22 @@ import os
 import sys
 import shutil
 import time
+import types
 import ntpath
 import posixpath
 import textwrap
 import platform
 import importlib
 import operator
+import datetime
+import subprocess
+import re
 
 import pytest
 import packaging.version
 
 import path
-from path import tempdir
+from path import TempDir
 from path import CaseInsensitivePattern as ci
 from path import SpecialResolver
 from path import Multi
@@ -232,6 +236,27 @@ class TestBasics:
         assert res2 == 'foo/bar'
 
 
+class TestPerformance:
+    def test_import_time(self, monkeypatch):
+        """
+        Import of path.py should take less than 100ms.
+
+        Run tests in a subprocess to isolate from test suite overhead.
+        """
+        cmd = [
+            sys.executable,
+            '-m', 'timeit',
+            '-n', '1',
+            '-r', '1',
+            'import path',
+        ]
+        res = subprocess.check_output(cmd, universal_newlines=True)
+        dur = re.search(r'(\d+) msec per loop', res).group(1)
+        limit = datetime.timedelta(milliseconds=100)
+        duration = datetime.timedelta(milliseconds=int(dur))
+        assert duration < limit
+
+
 class TestSelfReturn:
     """
     Some methods don't necessarily return any value (e.g. makedirs,
@@ -271,7 +296,7 @@ class TestSelfReturn:
 
 class TestScratchDir:
     """
-    Tests that run in a temporary directory (does not test tempdir class)
+    Tests that run in a temporary directory (does not test TempDir class)
     """
     def test_context_manager(self, tmpdir):
         """Can be used as context manager for chdir."""
@@ -358,6 +383,11 @@ class TestScratchDir:
             assert d.glob('*') == [af]
             assert d.glob('*.html') == []
             assert d.glob('testfile') == []
+
+            # .iglob matches .glob but as an iterator.
+            assert list(d.iglob('*')) == d.glob('*')
+            assert isinstance(d.iglob('*'), types.GeneratorType)
+
         finally:
             af.remove()
 
@@ -686,7 +716,7 @@ class TestScratchDir:
         test('UTF-16')
 
     def test_chunks(self, tmpdir):
-        p = (tempdir() / 'test.txt').touch()
+        p = (TempDir() / 'test.txt').touch()
         txt = "0123456789"
         size = 5
         p.write_text(txt)
@@ -700,13 +730,13 @@ class TestScratchDir:
         reason="samefile not present",
     )
     def test_samefile(self, tmpdir):
-        f1 = (tempdir() / '1.txt').touch()
+        f1 = (TempDir() / '1.txt').touch()
         f1.write_text('foo')
-        f2 = (tempdir() / '2.txt').touch()
+        f2 = (TempDir() / '2.txt').touch()
         f1.write_text('foo')
-        f3 = (tempdir() / '3.txt').touch()
+        f3 = (TempDir() / '3.txt').touch()
         f1.write_text('bar')
-        f4 = (tempdir() / '4.txt')
+        f4 = (TempDir() / '4.txt')
         f1.copyfile(f4)
 
         assert os.path.samefile(f1, f2) == f1.samefile(f2)
@@ -872,7 +902,7 @@ class TestTempDir:
         """
         One should be able to readily construct a temporary directory
         """
-        d = tempdir()
+        d = TempDir()
         assert isinstance(d, path.Path)
         assert d.exists()
         assert d.isdir()
@@ -881,24 +911,24 @@ class TestTempDir:
 
     def test_next_class(self):
         """
-        It should be possible to invoke operations on a tempdir and get
+        It should be possible to invoke operations on a TempDir and get
         Path classes.
         """
-        d = tempdir()
+        d = TempDir()
         sub = d / 'subdir'
         assert isinstance(sub, path.Path)
         d.rmdir()
 
     def test_context_manager(self):
         """
-        One should be able to use a tempdir object as a context, which will
+        One should be able to use a TempDir object as a context, which will
         clean up the contents after.
         """
-        d = tempdir()
+        d = TempDir()
         res = d.__enter__()
-        assert res is d
+        assert res == path.Path(d)
         (d / 'somefile.txt').touch()
-        assert not isinstance(d / 'somefile.txt', tempdir)
+        assert not isinstance(d / 'somefile.txt', TempDir)
         d.__exit__(None, None, None)
         assert not d.exists()
 
@@ -906,10 +936,10 @@ class TestTempDir:
         """
         The context manager will not clean up if an exception occurs.
         """
-        d = tempdir()
+        d = TempDir()
         d.__enter__()
         (d / 'somefile.txt').touch()
-        assert not isinstance(d / 'somefile.txt', tempdir)
+        assert not isinstance(d / 'somefile.txt', TempDir)
         d.__exit__(TypeError, TypeError('foo'), None)
         assert d.exists()
 
@@ -919,7 +949,7 @@ class TestTempDir:
         provide a temporry directory that will be deleted after that.
         """
 
-        with tempdir() as d:
+        with TempDir() as d:
             assert d.isdir()
         assert not d.isdir()
 
@@ -1193,5 +1223,15 @@ class TestMultiPath:
         assert path == input
 
 
-if __name__ == '__main__':
-    pytest.main()
+@pytest.mark.xfail('path.PY2', reason="Python 2 has no __future__")
+def test_no_dependencies():
+    """
+    Path.py guarantees that the path module can be
+    transplanted into an environment without any dependencies.
+    """
+    cmd = [
+        sys.executable,
+        '-S',
+        '-c', 'import path',
+    ]
+    subprocess.check_call(cmd)
